/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <device.h>
#include "project.h"
#include <stdio.h>
#include "Thermistor.h"

#define ADC_Ch0_Therm       0u
#define ADC_Ch1_Vhi         1u
#define ADC_Ch2_Vlow        2u
#define ADC_Ch3_Bat         3u
#define ADC_Ch4_Dim         4u
#define ADC_Ch5_Mode        6u

#define Low                 0u
#define Hi                  1u

int main(void)
{
    /* Voltages across reference resistor and thermistor*/
	int16 iVref, iVtherm,Vhi_mV,Vtherm_mV,Vlow_mV   ;
    
	/* Resistance of Thermistor*/
	uint32 iRes;
	
	/* Temperature value in 100ths of a degree C*/
	int32 iTemp; 
    
    /*Decimal Temp*/
    int32 decTemp;
    
    /*Fractional Temp*/
    int32 fracTemp;
	
	/* Dispaly format string */
	char printBuf[16]={'\0'};

	/*Start all the hardware components required*/
	ADC_Start();
	UART_Start();
	
	/*Enable Global Interrupts*/
	CyGlobalIntEnable;

    for(;;)
    {
    /* Pull thermister pin to ground to start measurments */   
    SWTherm_Write(Low);
    
    /*Read Voltages at Vhi, Vtherm, Vlow */
    while(ADC_Calibrate());                                
    Vtherm_mV = ADC_ReadResult_mVolts(ADC_Ch0_Therm);      
    while(ADC_Calibrate());                                
    Vhi_mV = ADC_ReadResult_mVolts(ADC_Ch1_Vhi);           
    while(ADC_Calibrate());                                
    Vlow_mV = ADC_ReadResult_mVolts(ADC_Ch2_Vlow);         
  
    /* Calulate voltage(mV)accross Referance resistor and accross thermistor */
    iVref = (Vhi_mV - Vtherm_mV);                          
    iVtherm = (Vtherm_mV - Vlow_mV);
    
    /*Pull thermister pin to Vdd to stop measurments (eliminating slef heating) */
    SWTherm_Write(Hi);                                     
		
	    /* Use the thermistor component API function call to obtain the temperature corresponding to the voltages measured*/
        
    	iRes = Thermistor_GetResistance(iVref, iVtherm);
    	iTemp = Thermistor_GetTemperature(iRes);
        
        /*Display -- For Debug*/	

        /*Determine decimal portion of temperature by dividing temperature by 100*/
        decTemp = iTemp/100;
        
        /*Determine fraction portion of temperature by subtracting decimal portion from result*/
        fracTemp = iTemp - (decTemp * 100);
        /*If fractional temperature is negative make it positive*/
        if(fracTemp < 0)
        {
            fracTemp *= -1;
        }
        
        /*format string to print out over UART*/
        sprintf(printBuf, "Temp=%ld.%01ld    ", decTemp, fracTemp); 
		
        /*Print result over UART*/
        UART_UartPutString(printBuf);
        UART_UartPutString("\n\r");
    }
}

/* [] END OF FILE */
